@@ -1,4 +1,11 @@
 # -*- coding: utf-8 -*-
+
+'''
+Advanced Interface Switcher
+2010-2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
+System menu plugin class
+'''
+
 import gobject, gtk, hildon
 from hildondesktop import StatusMenuItem
 import dbus
@@ -10,7 +17,6 @@ from advpowcommon.ui.Gtk import *
 from advpowcommon.ui.Notebook import NotebookMaemo5
 from advifswlib.interfaces.GSM import GSMInterface
 from advifswlib.interfaces.BT import BTInterface
-from advifswlib.interfaces.FlightMode import FlightMode
 from advifswlib.interfaces.WLAN import WLANInterface
 from advifswlib.util.config import *
 from advifswlib.util.locale import *
