@@ -1,7 +1,13 @@
 # -*- coding: utf-8 -*-
+
+'''
+Advanced Interface Switcher
+2010-2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
+Abstract interface object
+'''
+
 import gtk, hildon, dbus
 from advpowcommon.ui.Banners import HildonBanner
-from advpowcommon.ui.Cachers import DITPixbufCacher
 from advpowcommon.ui.Animation import DITPBCachedAnimator
 from advpowcommon.ui.ToggleControl import ToggleControlMaemo5
 from advpowcommon.util.execn import *
@@ -25,7 +31,7 @@ class AbstractInterface():
     self.__config = get_config()
     self.pre_init()
     self.__name = self.state['name']
-    self.__config_show_state_dialog = 'settings/%s/show-state-dialog' % (self.__name.lower())
+    self.__config_path = 'settings/%s' % (self.__name.lower())
     self.__button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
     self.__button.set_image(gtk.Image())
     self.__button.set_image_position(gtk.POS_LEFT)
@@ -37,10 +43,8 @@ class AbstractInterface():
     self.__button.tap_and_hold_setup(None, None, 0)
     self.__button.connect('tap-and-hold', self.__button_tap_and_hold)
     self.__button.connect('destroy', self.__destroy)
-
     self.__smi_cacher = get_cacher()
     self.__smi_animator = DITPBCachedAnimator([], self.__button.get_image().set_from_pixbuf, cacher=self.__smi_cacher, time_out=250)
-
     self.state_control = None
     self.mode_control = None
 
@@ -70,24 +74,21 @@ class AbstractInterface():
   def get_bus(self):
     return self.__bus
 
+  def destroy(self):
+    self.__destroy()
+
   def __destroy(self, button=None):
     self.__destroy_signals()
     self.__destroy_interfaces()
 
   def __init_signals(self):
-    for key in self.state['dbus']:
-      self.__init_signal(key)
+    for key in self.state['dbus']: self.__init_signal(key)
 
   def __init_signal(self, x):
     try:
       def callback(*args, **kwargs): self.__received_signal(x, *args, **kwargs)
       setattr(self, 'received_%s' % x, callback)
-      self.state['dbus'][x]['match'] = self.__bus.add_signal_receiver(
-        getattr(self, 'received_%s' % x), 
-        signal_name=self.state['dbus'][x]['name'], 
-        dbus_interface=self.state['dbus'][x]['iface'], 
-        path=self.state['dbus'][x]['path'], 
-        **self.state['dbus'][x]['args'])
+      self.state['dbus'][x]['match'] = self.__bus.add_signal_receiver(getattr(self, 'received_%s' % x), signal_name=self.state['dbus'][x]['name'], dbus_interface=self.state['dbus'][x]['iface'], path=self.state['dbus'][x]['path'], **self.state['dbus'][x]['args'])
     except:
       pass
 
@@ -105,25 +106,23 @@ class AbstractInterface():
     receiver_match.remove()
 
   def __received_signal(self, key, *args, **kwargs):
+    try: value, mode, strength = getattr(self, 'process_signal_%s' % key)(*args, **kwargs)
+    except: pass
     show_banner = False
     update_ui = False
-    value, mode, strength = getattr(self, 'process_signal_%s' % key)(*args, **kwargs)
     if value != None and value != self.state['value']:
       self.state['value'] = value
       show_banner = True
       update_ui = True
-      if self.state_control:
-        self.state_control.set_active(value)
+      if self.state_control: self.state_control.set_active(value)
     if mode != None and mode != self.state['mode']:
       self.state['mode'] = mode
       show_banner = True
-      if self.mode_control:
-        self.mode_control.set_active(mode)
+      if self.mode_control: self.mode_control.set_active(mode)
     if strength != None and strength != self.state['strength']:
       self.state['strength'] = strength
       update_ui = True
-    if update_ui:
-      self.__update_ui()
+    if update_ui: self.__update_ui()
     windex = self.state['value']
     if show_banner and self.state['banner'][windex]:
       text = '%s: %s' % (self.__name, self.__lcl.get_item(self.state['text'][windex]))
@@ -150,8 +149,7 @@ class AbstractInterface():
 
   def get_interface(self, x):
     try:
-      if self.__interfaces[x] == None:
-        self.__init_interface(x)
+      if self.__interfaces[x] == None: self.__init_interface(x)
       return self.__interfaces[x]
     except:
       return None
@@ -160,13 +158,11 @@ class AbstractInterface():
     for x in self.interfaces: self.__destroy_interface(x)
 
   def __destroy_interface(self, x):
-    try:
-      self.__interfaces[x] = None
-    except:
-      pass
+    try: self.__interfaces[x] = None
+    except: pass
 
   def __get_status(self):
-    self.state['value'], self.state['mode'], self.state['strength'] = getattr(self, 'get_status')()
+    self.state['value'], self.state['mode'], self.state['strength'] = self.get_status()
     self.__update_ui()
 
   def switched(self):
@@ -176,25 +172,22 @@ class AbstractInterface():
   def __update_ui(self):
     windex = self.state['value']
     image = self.state['images'][windex]
-    if windex == 2 and self.state['strength'] > 0:
-      image = self.state['images_st'][self.state['strength']]
+    if windex == 2 and self.state['strength'] > 0: image = self.state['images_st'][self.state['strength']]
     self.__set_si(image)
     self.__button.set_value(self.__lcl.get_item(self.state['text'][windex]))
 
   def __button_clicked(self, button=None, user_data=None):
-    return self.__switch(self.__config.get_value(self.__config_show_state_dialog))
+    return self.__switch(self.__config.get_value('%s/show-state-dialog' % (self.__config_path)))
 
   def __button_tap_and_hold(self, button=None, user_data=None):
-    return self.__switch(not(self.__config.get_value(self.__config_show_state_dialog)))
+    return self.__switch(not(self.__config.get_value('%s/show-state-dialog' % (self.__config_path))))
 
   def __switch(self, show_dialog):
     if not self.__processing:
       self.__processing = True
       self.start_animation()
-      if show_dialog:
-        gobject.idle_add(self.__show_switch_dialog)
-      else:
-        self.__switch_state(int(self.state['value'] == 0))
+      if show_dialog: gobject.idle_add(self.__show_switch_dialog)
+      else: self.__switch_state(int(self.state['value'] == 0))
       self.__button.get_toplevel().hide()
     return True
 
@@ -219,19 +212,16 @@ class AbstractInterface():
     self.__processing = False
 
   def __get_state_controls(self):
-    texts = list(self.state['text'])
-    texts = map(self.__lcl.get_item, texts)
+    texts = map(self.__lcl.get_item, list(self.state['text']))
     return zip(texts, [self.__turn_state for t in texts])
 
   def __get_mode_controls(self):
-    texts = list(self.state['modes'])
-    texts = map(self.__lcl.get_item, texts)
+    texts = map(self.__lcl.get_item, list(self.state['modes']))
     return zip(texts, [self.__turn_mode for t in texts])
 
   def __turn_state(self, widget=None, control=None, cstate=None):
     if widget.get_active():
-      if not(cstate):
-        cstate = control.get_active()
+      if not(cstate): cstate = control.get_active()
       chstate = min(1, cstate)
       state = self.state['value']
       if cstate != state:
@@ -246,10 +236,8 @@ class AbstractInterface():
 
   def __turn_mode(self, widget=None, control=None, cmode=None):
     if widget.get_active():
-      if cmode == None or cmode == ():
-        cmode = control.get_active()
-      if cmode != self.state['mode']:
-        self.turn_mode(cmode)
+      if cmode == None or cmode == (): cmode = control.get_active()
+      if cmode != self.state['mode']: self.turn_mode(cmode)
 
   def turn_mode(self, mode):
     pass
@@ -259,10 +247,8 @@ class AbstractInterface():
     if new_state != cstate:
       self.__button.set_value('...')
       try:
-        if new_state:
-          self.turn_on()
-        else:
-          self.turn_off()
+        if new_state: self.turn_on()
+        else: self.turn_off()
       except:
         self.switched()
         self.__update_ui()
@@ -284,7 +270,5 @@ class AbstractInterface():
 
   def __set_sai(self, key):
     if any(self.state['show']):
-      if self.state['show'][self.state['value']]:
-        self.__set_status_area_icon(self.__name, key)
-      else:
-        self.__set_status_area_icon(self.__name, None, False)
+      if self.state['show'][self.state['value']]: self.__set_status_area_icon(self.__name, key)
+      else: self.__set_status_area_icon(self.__name, None, False)
