@@ -1,4 +1,12 @@
 # -*- coding: utf-8 -*-
+
+'''
+Advanced Interface Switcher
+2010-2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
+Bluetooth interface object
+'''
+
+
 import gobject
 from advifswlib.interfaces.Abstract import AbstractInterface
 from advpowcommon.util.execn import *
@@ -40,28 +48,21 @@ class BTInterface(AbstractInterface):
         return 2, None, None
       else:
         self.connected_device.remove(device)
-        if len(self.connected_device) == 0:
-          return self.get_status()
-        else:
-          return None, None, None
+        if len(self.connected_device) == 0: return self.get_status()
+        else: return None, None, None
     else:
       return None, None, None
 
   def process_signal_on(self, prop, value, **kwargs):
     prop = str(prop)
-    if (prop == 'Powered'):
-      return int(value), None, None
-    elif (prop == 'Discoverable'):
-      return None, int(value), None
-    else:
-      return None, None, None
+    if (prop == 'Powered'): return int(value), None, None
+    elif (prop == 'Discoverable'): return None, int(value), None
+    else: return None, None, None
 
   def get_status(self):
     props = self.get_interface('BlueZAdapter').GetProperties()
-    if props['Powered']:
-      return int(props['Powered']), int(props['Discoverable']), 0
-    else:
-      return 0, 0, 0
+    if props['Powered']: return int(props['Powered']), int(props['Discoverable']), 0
+    else: return 0, 0, 0
 
   def turn_on(self):
     gobject.idle_add(self.run_commands, True)
