@@ -1,6 +1,12 @@
 # -*- coding: utf-8 -*-
-import gobject
 
+'''
+Advanced Interface Switcher
+2010-2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
+GSM interface object
+'''
+
+import gobject
 from advpowcommon.util.execn import *
 from advifswlib.interfaces.Abstract import AbstractInterface
 
@@ -26,7 +32,7 @@ class GSMInterface(AbstractInterface):
       'connected': {'name': self.gsm_module_signal, 'iface': self.gsm_module_iface, 'path': self.gsm_module_path, 'args': {}},
       'strength': {'name': self.strength_signal, 'iface': self.phone_iiface, 'path': self.phone_path, 'args': {}}
     },
-    'images': ('ifsw_statusarea_cell_off', 'ifsw_statusarea_cell_on', 'ifsw_statusarea_cell_online'),
+    'images': ('ifsw_statusarea_cell_off', 'ifsw_statusarea_cell_signal_0', 'ifsw_statusarea_cell_signal_5'),
     'images_st': ('ifsw_statusarea_cell_signal_0', 'ifsw_statusarea_cell_signal_1', 'ifsw_statusarea_cell_signal_2', 'ifsw_statusarea_cell_signal_3', 'ifsw_statusarea_cell_signal_4', 'ifsw_statusarea_cell_signal_5'),
     'text': ('Off', 'On', '<>'),
     'show': (True, True, False),
@@ -42,15 +48,8 @@ class GSMInterface(AbstractInterface):
     return self.get_status()
 
   def process_signal_connected(self, value):
-    try:
-      result = 1 + ['activation_pending', 'online'].index(str(value))
-      mode = self.get_mode()
-      strength = self.get_strength()
-    except:
-      result = None
-      mode = None
-      strength = None
-    return result, mode, strength
+    try: return 1 + ['activation_pending', 'online'].index(str(value)), self.get_mode(), self.get_strength()
+    except: return None, None, None
 
   def process_signal_strength(self, arg1, arg2):
     return None, None, self.get_strength_value(arg1)
@@ -63,14 +62,10 @@ class GSMInterface(AbstractInterface):
         result = 1
       elif status in (0,1,2):
         result = 2
-      mode = self.get_mode()
-      strength = self.get_strength()
+      return result, self.get_mode(), self.get_strength()
     except Exception, e:
       print e
-      result = 0
-      mode = 0
-      strength = 0
-    return result, mode, strength
+      return None, None, None
 
   def turn_on(self):
     gobject.idle_add(self.run_commands, True)
