@@ -1,4 +1,11 @@
 # -*- coding: utf-8 -*-
+
+'''
+Advanced Interface Switcher
+2010-2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
+WLAN interface object
+'''
+
 import dbus, gobject
 from advifswlib.interfaces.Abstract import AbstractInterface
 from advpowcommon.util.execn import *
@@ -23,7 +30,7 @@ class WLANInterface(AbstractInterface):
       'connected': {'name': self.wifi_icd2_state_signal, 'iface': self.wifi_icd2_iface, 'path': self.wifi_icd2_path, 'args': {}},
       'statistics': {'name': self.wifi_icd2_statistics_signal, 'iface': self.wifi_icd2_iface, 'path': self.wifi_icd2_path, 'args': {}}
     },
-    'images': ('ifsw_statusarea_wlan_off', 'ifsw_statusarea_wlan_on', 'ifsw_statusarea_wlan_online'),
+    'images': ('ifsw_statusarea_wlan_off', 'ifsw_statusarea_wlan_signal_0', 'ifsw_statusarea_wlan_signal_3'),
     'images_st': ('ifsw_statusarea_wlan_signal_0', 'ifsw_statusarea_wlan_signal_1', 'ifsw_statusarea_wlan_signal_1', 'ifsw_statusarea_wlan_signal_2', 'ifsw_statusarea_wlan_signal_3', 'ifsw_statusarea_wlan_signal_3'),
     'text': ('Off', 'On', '<>'),
     'show': (True, False, False),
@@ -36,10 +43,8 @@ class WLANInterface(AbstractInterface):
     self.interfaces = {'ICD': [self.wifi_icd2_iface, self.wifi_icd2_path, self.wifi_icd2_iface, '/usr/sbin/icd2', False]}
 
   def process_signal_on(self, *args, **kwargs):
-    if args[0] == '/org/freedesktop/Hal/devices/platform_wl12xx':
-      return int(kwargs['member'] == 'DeviceAdded'), 0, None
-    else:
-      return None, None, None
+    if args[0] == '/org/freedesktop/Hal/devices/platform_wl12xx': return int(kwargs['member'] == 'DeviceAdded'), 0, None
+    else: return None, None, None
 
   def process_signal_connected(self, *args):
     if len(args) == 8 and args[3].startswith('WLAN_'):
@@ -50,7 +55,8 @@ class WLANInterface(AbstractInterface):
         return 1, 0, None
       else:
         return self.state['value'], 0, None
-    return None, None, None
+    else:
+      return None, None, None
 
   def process_signal_statistics(self, *args):
     return None, None, min(int(args[7]), 5)
@@ -58,10 +64,8 @@ class WLANInterface(AbstractInterface):
   def get_status(self):
     result = int(get_shell_command_output('lsmod | grep -o wl12xx') != '')
     if result:
-      try:
-        self.get_interface('ICD').state_req()
-      except:
-        self.reinit_interface('ICD')
+      try: self.get_interface('ICD').state_req()
+      except: self.reinit_interface('ICD')
     return result, 0, 0
 
   def turn_on(self):
@@ -69,20 +73,14 @@ class WLANInterface(AbstractInterface):
       #run_async(self.run_commands, (self.wifi_turn_on_cmd,))
       gobject.idle_add(self.run_commands, self.wifi_turn_on_cmd)
     elif self.state['value'] == 2:
-      try:
-        self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
-      except:
-        self.reinit_interface('ICD')
-        #self.get_interface('ICD').disconnect_req(dbus.UInt32(32768))
+      try: self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
+      except: self.reinit_interface('ICD')
 
   def turn_off(self):
     if self.state['value'] > 0:
       if self.state['value'] == 2:
-        try:
-          self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
-        except:
-          self.reinit_interface('ICD')
-          #self.get_interface('ICD').disconnect_req(dbus.UInt32(32768))
+        try: self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
+        except: self.reinit_interface('ICD')
       #run_async(self.run_commands, (self.wifi_turn_off_cmd,))
       gobject.idle_add(self.run_commands, self.wifi_turn_off_cmd)
 
@@ -92,11 +90,8 @@ class WLANInterface(AbstractInterface):
     self.switched()
 
   def scan_request(self):
-    try:
-      self.get_interface('ICD').scan_req(dbus.UInt32(0), dbus.Array([], signature='s'))
-    except:
-      self.reinit_interface('ICD')
-      #self.get_interface('ICD').scan_req(dbus.UInt32(0), dbus.Array([], signature='s'))
+    try: self.get_interface('ICD').scan_req(dbus.UInt32(0), dbus.Array([], signature='s'))
+    except: self.reinit_interface('ICD')
 
   def get_strength(self):
     if self.state['value'] == 2:
