@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
+
 '''
-Advanced Interface Switcher Config
+Advanced Interface Switcher Cacher
 2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
 '''
 
