@@ -12,7 +12,7 @@ class ISLocale(Locale):
     Locale.__init__(self)
 
   def initialize(self):
-    self.text_domain = 'interface-switcher'
+    self.text_domain = 'advanced-interface-switcher'
     self.current_dict = {
       'item-Bluetooth': 'Bluetooth',
       'item-GSM': 'GSM',
@@ -25,7 +25,10 @@ class ISLocale(Locale):
       'item-GSM':  '2G',
       'item-3G':  '3G',
       'item-Connectable': 'Connectable',
-      'item-Discoverable': 'Discoverable'
+      'item-Discoverable': 'Discoverable',
+      'settings/bluetooth/show-state-dialog': 'Bluetooth: dialog on click',
+      'settings/gsm/show-state-dialog': 'GSM: dialog on click',
+      'settings/wlan/show-state-dialog': 'WLAN: dialog on click'
     }
 
 islocale_singleton = ISLocale()
